@@ -17,6 +17,7 @@ def parse(
     key_epoch="epoch",
     key_iteration="iteration",
     key_elapsed_time="elapsed_time",
+    key_of_interest=None,
 ):
     """parse(root_dir, sort=None, q=None)
 
@@ -104,9 +105,12 @@ def parse(
 
             key = "{} (max)".format(col)
             log_keys.add(key)
-            index = log[col].idxmax()
+            if key_of_interest is None:
+                index = log[col].idxmax()
+            else:
+                index = log[key_of_interest].idxmax()
             if math.isnan(index):
-                break
+                continue
             datum[key] = (
                 log[col][index],
                 (log[key_epoch][index], log[key_iteration][index]),
@@ -114,7 +118,10 @@ def parse(
 
             key = "{} (min)".format(col)
             log_keys.add(key)
-            index = log[col].idxmin()
+            if key_of_interest is None:
+                index = log[col].idxmin()
+            else:
+                index = log[key_of_interest].idxmax()
             datum[key] = (
                 log[col][index],
                 (log[key_epoch][index], log[key_iteration][index]),
